]> Untitled Git - lemmy-ui.git/blobdiff - deploy.sh
fix submodule error
[lemmy-ui.git] / deploy.sh
index 58d1d7fb9c796b19f9bd7bc9dddc2c0112e1977e..e919779a57b6b4b86c2056c4c088f8376176add8 100755 (executable)
--- a/deploy.sh
+++ b/deploy.sh
@@ -1,10 +1,16 @@
 #!/bin/bash
+set -e
 
 new_tag="$1"
 
 # Old deploy
# sudo docker build . --tag dessalines/lemmy-ui:$new_tag
 # sudo docker push dessalines/lemmy-ui:$new_tag
 
+# Upgrade version
+yarn version --new-version $new_tag
+git push
+
 git tag $new_tag
 git push origin $new_tag
@@ -1,10 +1,16 @@
 
 # Old deploy
-# sudo docker build . --tag dessalines/lemmy-ui:$new_tag
+# sudo docker build . --tag dessalines/lemmy-ui:$new_tag --platform=linux/amd64 --push
+# sudo docker build . --tag dessalines/lemmy-ui:$new_tag --platform=linux/amd64
 # sudo docker push dessalines/lemmy-ui:$new_tag
 